@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2022 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2018 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -40,6 +40,7 @@ sub new {
     my $class = shift;
 
     my $self = $class->SUPER::new(@_);
+    die "Could not get NS PID of #1!\n" unless(defined($self->{nspid}));
 
     return bless $self, $class;
 }
@@ -49,16 +50,25 @@ sub check {
     my $pid = shift;
     my $bin = shift;
     my $norestart = shift;
+    my $ns = $self->get_nspid($pid);
 
     # stop here if no dedicated PID namespace is used
-    return 0 unless $self->in_pidns($pid);
+    return 0 if(!$ns || $ns == $self->{nspid});
 
-    my $cg = nr_get_cgroup($pid);
+    unless(open(FCG, qq(/proc/$pid/cgroup))) {
+	print STDERR "$LOGPREF #$pid: unable to open cgroup ($!)\n" if($self->{debug});
+	return 0;
+    }
+    my $cg;
+    {
+	local $/;
+	$cg = <FCG>;
+	close(FCG);
+    }
 
     # look for docker cgroups
-    return 0 unless($cg =~ m@^/system.slice/docker-(.+)\.scope$@ ||
-                    $cg =~ m@^/system.slice/docker\.service$@ ||
-                    $cg =~ m@^/docker/([\da-f]+)$@);
+    return 0 unless($cg =~ /^\d+:[^:]+:\/system.slice\/docker-(.+)\.scope$/m ||
+                    $cg =~ /^\d+:[^:]+:\/docker\/([\da-f]+)$/m);
 
     print STDERR "$LOGPREF #$pid is part of docker container '$1' and will be ignored\n" if($self->{debug});
 
