@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2018 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,6 @@ use strict;
 use warnings;
 
 use parent qw(NeedRestart::Interp);
-use Getopt::Long;
 use NeedRestart qw(:interp);
 use NeedRestart::Utils;
 
@@ -56,7 +55,7 @@ sub files {
     my $pid = shift;
 
     my %ret = map {
-	my $stat = nr_stat($_);
+	my $stat = nr_stat("/proc/$pid/root/$_");
 	$_ => ( defined($stat) ? $stat->{ctime} : undef );
     } map {
 	my $l = readlink;
