@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2022 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2018 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -29,22 +29,20 @@ use warnings;
 
 use parent qw(NeedRestart::Interp);
 use Cwd qw(abs_path getcwd);
-use File::Temp qw(tempdir);
 use Getopt::Std;
 use NeedRestart qw(:interp);
 use NeedRestart::Utils;
 
 my $LOGPREF = '[Python]';
-my $empty_dir;
 
-needrestart_interp_register(__PACKAGE__, "python");
+needrestart_interp_register(__PACKAGE__);
 
 sub isa {
     my $self = shift;
     my $pid = shift;
     my $bin = shift;
 
-    return 1 if($bin =~ m@^/usr/(local/)?bin/python([23][.\d]*)?$@);
+    return 1 if($bin =~ m@/usr/(local/)?bin/python@);
 
     return 0;
 }
@@ -57,7 +55,7 @@ sub _scan($$$$$) {
     my $path = shift;
 
     my $fh;
-    open($fh, '<', "/proc/$pid/root/$src") || return;
+    open($fh, '<', $src) || return;
     # find used modules
     my %modules = map {
 	(/^\s*import\s+(\S+)/ ? ($1 => 1) : (/^\s*from\s+(\S+)\s+import\s+/ ? ($1 => 1) : ()))
@@ -81,32 +79,17 @@ sub _scan($$$$$) {
     }
 }
 
-# chdir into empty directory to prevent python parsing arbitrary files
-sub chdir_empty() {
-    unless(defined($empty_dir)) {
-        $empty_dir = tempdir(CLEANUP => 1);
-    }
-    chdir($empty_dir);
-}
-
 sub source {
     my $self = shift;
     my $pid = shift;
     my $ptable = nr_ptable_pid($pid);
     unless($ptable->{cwd}) {
 	print STDERR "$LOGPREF #$pid: could not get current working directory, skipping\n" if($self->{debug});
-	return undef;
+	return ();
     }
     my $cwd = getcwd();
     chdir("/proc/$pid/root/$ptable->{cwd}");
 
-    # skip the process if the cwd is unreachable (i.e. due to mnt ns)
-    unless(getcwd()) {
-	chdir($cwd);
-	print STDERR "$LOGPREF #$pid: process cwd is unreachable\n" if($self->{debug});
-	return undef;
-    }
-
     # get original ARGV
     (my $bin, local @ARGV) = nr_parse_cmd($pid);
 
@@ -156,7 +139,6 @@ sub files {
 
     # skip the process if the cwd is unreachable (i.e. due to mnt ns)
     unless(getcwd()) {
-	chdir($cwd);
 	print STDERR "$LOGPREF #$pid: process cwd is unreachable\n" if($self->{debug});
 	return ();
     }
@@ -195,41 +177,39 @@ sub files {
 
     # use cached data if avail
     if(exists($cache->{files}->{(__PACKAGE__)}->{$src})) {
-	chdir($cwd);
 	print STDERR "$LOGPREF #$pid: use cached file list\n" if($self->{debug});
 	return %{ $cache->{files}->{(__PACKAGE__)}->{$src} };
     }
 
     # prepare include path environment variable
-    my @path;
-    local %ENV;
-
-    # get include path from env
     my %e = nr_parse_env($pid);
+    local %ENV;
     if(exists($e{PYTHONPATH})) {
-	@path = split(':', $e{PYTHONPATH});
+	$ENV{PYTHONPATH} = $e{PYTHONPATH};
     }
-
-    # get include path from sys.path
-    chdir_empty();
+    elsif(exists($ENV{PYTHONPATH})) {
+	delete($ENV{PYTHONPATH});
+    }
+    
+    # get include path
     my ($pyread, $pywrite) = nr_fork_pipe2($self->{debug}, $ptable->{exec}, '-');
     print $pywrite "import sys\nprint(sys.path)\n";
     close($pywrite);
     my ($path) = <$pyread>;
     close($pyread);
-    chdir("/proc/$pid/root/$ptable->{cwd}");
-
+    
     # look for module source files
+    my @path;
     if(defined($path)) {
 	chomp($path);
 	$path =~ s/^\['//;
 	$path =~ s/'\$//;
-	push(@path, split("', '", $path));
+	@path = map { "/proc/$pid/root/$_"; } split("', '", $path);
     }
     else {
 	print STDERR "$LOGPREF #$pid: failed to retrieve include path\n" if($self->{debug});
     }
-
+    
     my %files;
     _scan($self->{debug}, $pid, $src, \%files, \@path);
 
