@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2025 (C) Thomas Liske <thomas@fiasko-nw.net>
+#   2013 - 2018 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -33,14 +33,6 @@ use Locale::TextDomain 'needrestart';
 
 needrestart_ui_register(__PACKAGE__, NEEDRESTART_PRIO_LOW);
 
-# The default is to be interactive
-my $INTERACTIVE = 1;
-
-sub interactive {
-    my $self = shift;
-    $INTERACTIVE = shift;
-}
-
 sub _announce {
     my $self = shift;
     my $message = shift;
@@ -51,7 +43,7 @@ sub _announce {
 					 kversion => $vars{KVERSION},
 					 message => $message,
 		   ));
-    <STDIN> if (-t *STDIN && -t *STDOUT && $INTERACTIVE);
+    <STDIN> if (-t *STDIN && -t *STDOUT);
 }
 
 
@@ -85,7 +77,7 @@ You should consider rebooting!
 
 EHINT
 
-    <STDIN> if (-t *STDIN && -t *STDOUT && $INTERACTIVE);
+    <STDIN> if (-t *STDIN && -t *STDOUT);
 }
 
 
@@ -98,7 +90,7 @@ sub announce_ucode {
 			 current => $vars{CURRENT},
 			 avail => $vars{AVAIL},
 		   ));
-    <STDIN> if (-t *STDIN && -t *STDOUT && $INTERACTIVE);
+    <STDIN> if (-t *STDIN && -t *STDOUT);
 }
 
 
